﻿Imports Telerik.WinControls.UI
Imports Telerik.WinControls.Layouts
Imports Telerik.WinControls

Public Class CustomListVisualItem
    Inherits RadListVisualItem

#Region "Fields"

    Private label As RadLabelElement
    Private checkBox As RadCheckBoxElement

#End Region

#Region "Initialization"

    Shared Sub New()
        RadListVisualItem.SynchronizationProperties.Add(CustomListDataItem.AvailableProperty)
        RadListVisualItem.SynchronizationProperties.Add(CustomListDataItem.NameProperty)
    End Sub

#End Region

#Region "Overrides"

    Protected Overrides ReadOnly Property ThemeEffectiveType() As Type
        Get
            Return GetType(RadListVisualItem)
        End Get
    End Property

    Protected Overrides Sub CreateChildElements()
        MyBase.CreateChildElements()

        Me.label = New RadLabelElement()
        Me.checkBox = New RadCheckBoxElement()

        AddHandler Me.checkBox.ToggleStateChanged, AddressOf ToggleStateChanged
        Me.label.StretchHorizontally = True
        Dim stack As StackLayoutPanel = New StackLayoutPanel()
        stack.Orientation = Orientation.Horizontal
        stack.Children.Add(checkBox)
        stack.Children.Add(label)
        Me.Children.Add(stack)
    End Sub

    Protected Overrides Sub PropertySynchronized(ByVal [property] As RadProperty)
        Dim dataItem As CustomListDataItem = CType(Me.Data, CustomListDataItem)

        If [property] Is CustomListDataItem.AvailableProperty Then
            Dim newValue As Boolean = dataItem.Available

            Me.checkBox.Checked = newValue

            Dim itemName As String = dataItem.Name
            Me.label.Text = Me.GetAvailabilityText(itemName, newValue)
        End If

        If [property] Is CustomListDataItem.NameProperty Then
            Dim itemName As String = dataItem.Name
            Dim available As Boolean = dataItem.Available
            Me.label.Text = Me.GetAvailabilityText(itemName, available)
        End If

        Me.Text = ""
    End Sub

#End Region

#Region "Private Methods"

    Private Function GetAvailabilityText(ByVal itemName As String, ByVal available As Boolean) As String
        Dim yesno As String
        If available Then
            yesno = " "
        Else
            yesno = " not "
        End If
        Return itemName & " is" & yesno & "available"
    End Function

    Private Sub ToggleStateChanged(ByVal sender As Object, ByVal args As StateChangedEventArgs)
        CType(Me.Data.DataBoundItem, BussinessObject).Available = Me.checkBox.Checked
    End Sub

#End Region
End Class
